Authors & Roles
===============

Lead Developers
---------------
- `Yalin Li`_ (current maintainer)
- `Joy Zhang`_


Tutorials and Videos
--------------------
- `Yalin Li`_
- `Joy Zhang`_
- `Tori Morgan <https://qsdsan.readthedocs.io/en/beta/authors/Tori_Morgan.html>`_
- `Hannah Lohman <https://qsdsan.readthedocs.io/en/beta/authors/Hannah_Lohman.html>`_


Module Development
------------------
- `Yalin Li`_
- `Joy Zhang`_
- `Stetson Rowles <https://qsdsan.readthedocs.io/en/beta/authors/Stetson_Rowles.html>`_
- Smiti Mittal
- Anna Kogler
- Samuel Aguiar
- Tyler Stephen
- Shion Watabe
- `Other developers <https://github.com/QSD-Group/QSDsan/graphs/contributors>`_ that have contributed to the repository.


Funding Support
---------------
- `Jeremy Guest <mailto:jsguest@illinois.edu>`_
- `Ro Cusick <mailto:rcusick@illinois.edu>`_
- `William Tarpeh <mailto:wtarpeh@stanford.edu>`_


Special Acknowledgement
-----------------------
- Yoel Cortés-Peña for helping many of the ``QSDsan`` members get started on Python and package development.


.. Links
.. _Yalin Li: https://qsdsan.readthedocs.io/en/beta/authors/Yalin_Li.html
.. _Joy Zhang: https://qsdsan.readthedocs.io/en/beta/authors/Joy_Zhang.html
